@@ -5,7 +5,7 @@ start_server {tags {"modules"}} {
     r module load $testmodule
     test {Config get commands work} {
         # Make sure config get module config works
-        assert_equal [lindex [lindex [r module list] 0] 1] moduleconfigs
+        assert_not_equal [lsearch [lmap x [r module list] {dict get $x name}] moduleconfigs] -1
         assert_equal [r config get moduleconfigs.mutable_bool] "moduleconfigs.mutable_bool yes"
         assert_equal [r config get moduleconfigs.immutable_bool] "moduleconfigs.immutable_bool no"
         assert_equal [r config get moduleconfigs.memory_numeric] "moduleconfigs.memory_numeric 1024"
@@ -77,6 +77,10 @@ start_server {tags {"modules"}} {
         assert_match {*must be one of the following*} $e
     }
 
+    test {test blocking of config registration and load outside of OnLoad} {
+        assert_equal [r block.register.configs.outside.onload] OK
+    }
+
     test {Unload removes module configs} {
         r module unload moduleconfigs
         assert_equal [r config get moduleconfigs.*] ""
@@ -94,7 +98,7 @@ start_server {tags {"modules"}} {
 
     test {test loadex functionality} {
         r module loadex $testmodule CONFIG moduleconfigs.mutable_bool no CONFIG moduleconfigs.immutable_bool yes CONFIG moduleconfigs.memory_numeric 2mb CONFIG moduleconfigs.string tclortickle
-        assert_equal [lindex [lindex [r module list] 0] 1] moduleconfigs
+        assert_not_equal [lsearch [lmap x [r module list] {dict get $x name}] moduleconfigs] -1
         assert_equal [r config get moduleconfigs.mutable_bool] "moduleconfigs.mutable_bool no"
         assert_equal [r config get moduleconfigs.immutable_bool] "moduleconfigs.immutable_bool yes"
         assert_equal [r config get moduleconfigs.memory_numeric] "moduleconfigs.memory_numeric 2097152"
@@ -157,7 +161,7 @@ start_server {tags {"modules"}} {
     test {test config rewrite with dynamic load} {
         #translates to: super \0secret password
         r module loadex $testmodule CONFIG moduleconfigs.string \x73\x75\x70\x65\x72\x20\x00\x73\x65\x63\x72\x65\x74\x20\x70\x61\x73\x73\x77\x6f\x72\x64 ARGS
-        assert_equal [lindex [lindex [r module list] 0] 1] moduleconfigs
+        assert_not_equal [lsearch [lmap x [r module list] {dict get $x name}] moduleconfigs] -1
         assert_equal [r config get moduleconfigs.string] "moduleconfigs.string {super \0secret password}"
         r config set moduleconfigs.mutable_bool yes
         r config set moduleconfigs.memory_numeric 750
@@ -207,7 +211,7 @@ start_server {tags {"modules"}} {
     test {test 1.module load 2.config rewrite 3.module unload 4.config rewrite works} {
         # Configs need to be removed from the old config file in this case.
         r module loadex $testmodule CONFIG moduleconfigs.memory_numeric 500 ARGS
-        assert_equal [lindex [lindex [r module list] 0] 1] moduleconfigs
+        assert_not_equal [lsearch [lmap x [r module list] {dict get $x name}] moduleconfigs] -1
         r config rewrite
         r module unload moduleconfigs
         r config rewrite
@@ -217,34 +221,18 @@ start_server {tags {"modules"}} {
     }
     test {startup moduleconfigs} {
         # No loadmodule directive
-        set nomodload [start_server [list overrides [list moduleconfigs.string "hello"]]]
-        wait_for_condition 100 50 {
-            ! [is_alive $nomodload]
-        } else {
-            fail "startup should've failed with no load and module configs supplied"
-        }
-        set stdout [dict get $nomodload stdout]
-        assert_equal [count_message_lines $stdout "Module Configuration detected without loadmodule directive or no ApplyConfig call: aborting"] 1
+        catch {exec src/redis-server --moduleconfigs.string "hello"} err
+        assert_match {*Module Configuration detected without loadmodule directive or no ApplyConfig call: aborting*} $err
 
         # Bad config value
-        set badconfig [start_server [list overrides [list loadmodule "$testmodule" moduleconfigs.string "rejectisfreed"]]]
-        wait_for_condition 100 50 {
-            ! [is_alive $badconfig]
-        } else {
-            fail "startup with bad moduleconfigs should've failed"
-        }
-        set stdout [dict get $badconfig stdout]
-        assert_equal [count_message_lines $stdout "Issue during loading of configuration moduleconfigs.string : Cannot set string to 'rejectisfreed'"] 1
+        catch {exec src/redis-server --loadmodule "$testmodule" --moduleconfigs.string "rejectisfreed"} err
+        assert_match {*Issue during loading of configuration moduleconfigs.string : Cannot set string to 'rejectisfreed'*} $err
 
-        set noload [start_server [list overrides [list loadmodule "$testmodule noload" moduleconfigs.string "hello"]]]
-        wait_for_condition 100 50 {
-            ! [is_alive $noload]
-        } else {
-            fail "startup with moduleconfigs and no loadconfigs call should've failed"
-        }
-        set stdout [dict get $noload stdout]
-        assert_equal [count_message_lines $stdout "Module Configurations were not set, likely a missing LoadConfigs call. Unloading the module."] 1
+        # missing LoadConfigs call
+        catch {exec src/redis-server --loadmodule "$testmodule" noload --moduleconfigs.string "hello"} err
+        assert_match {*Module Configurations were not set, likely a missing LoadConfigs call. Unloading the module.*} $err
 
+        # successful
         start_server [list overrides [list loadmodule "$testmodule" moduleconfigs.string "bootedup" moduleconfigs.enum two moduleconfigs.flags "two four"]] {
             assert_equal [r config get moduleconfigs.string] "moduleconfigs.string bootedup"
             assert_equal [r config get moduleconfigs.mutable_bool] "moduleconfigs.mutable_bool yes"
